@@ -4,7 +4,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "2.01";
+our $VERSION = "2.02";
 
 use Mouse;
 use Carp qw/confess/;
@@ -78,17 +78,18 @@ sub _build_enum {
             if (exists $child->_enums->{$id}) {
                 confess "id `$id` is duplicate."
             }
-            $child->_enums->{$id} = undef;
+            my $instance = $child->new(
+                id => $id,
+                %args
+            );
+            $child->_enums->{$id} = $instance;
 
             *{"${child}\::${sub_name}"} = sub {
                 my $class = shift;
                 if ($class && $class ne $child) {
                     confess "`${child}::$sub_name` can only be called as static method of `$child`. Please call `${child}->${sub_name}`.";
                 }
-                return $class->_enums->{$id} //= $class->new(
-                    id => $id,
-                    %args
-                );
+                return $instance;
             }
         }
     }
